pub enum BindError {
UnsupportedVersion {
interface: &'static str,
requested: u32,
available: u32,
},
NotPresent(&'static str),
}Expand description
An error that occurs when a binding a global fails.
Variants
UnsupportedVersion
The requested version of the global is not supported.
Fields

requested: u32The lowest version that was requested by the caller, must be greater than Self::UnsupportedVersion::requested.

available: u32The actual verison that was available on the server, must be less than Self::UnsupportedVersion::requested.
NotPresent(&'static str)
The requested global was not found in the registry.