pub struct Global {
pub name: u32,
pub interface: String,
pub version: u32,
}Expand description
Description of a global.
Fields
name: u32The name of the global.
This is an identifier used by the server to reference some specific global.
interface: StringThe interface of the global.
This describes what type of protocol object the global is.
version: u32The advertised version of the global.
This specifies the maximum version of the global that may be bound. This means any lower version of the global may be bound.