GlobalListContents

Struct GlobalListContents 

pub struct GlobalListContents { /* private fields */ }
A container representing the current contents of the list of globals

Implementations

Source

impl GlobalListContents

pub fn with_list<T, F: FnOnce(&[Global]) -> T>(&self, f: F) -> T

Access the list of globals

Your closure is invoked on the global list, and its return value is forwarded to the return value of this function. This allows you to process the list without making a copy.

pub fn clone_list(&self) -> Vec<Global>

Get a copy of the contents of the list of globals.